%define major		1
%define libname		%mklibname fido 2 %{major}
%define develname	%mklibname fido 2 -d

Name:           libfido2
Version:        1.15.0
Release:        %mkrel 3
Summary:        FIDO2 library
Group:          System/Libraries

License:        BSD-2-Clause
URL:            https://github.com/Yubico/%{name}
Source0:        https://developers.yubico.com/%{name}/Releases/%{name}-%{version}.tar.gz
Source1:        https://developers.yubico.com/%{name}/Releases/%{name}-%{version}.tar.gz.sig

BuildRequires:  gnupg2
BuildRequires:  cmake
BuildRequires:  make
BuildRequires:  gcc
BuildRequires:  pkgconfig(libcbor)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(zlib)

%description
%{name} is an open source library to support the FIDO2 protocol.  FIDO2 is
an open authentication standard that consists of the W3C Web Authentication
specification (WebAuthn API), and the Client to Authentication Protocol
(CTAP).  CTAP is an application layer protocol used for communication
between a client (browser) or a platform (operating system) with an external
authentication device (for example the Yubico Security Key).

%package -n %{libname}
Summary:        Libraries for %{name}
Group:          System/Libraries

%description -n %{libname}
Libraries for %{name}.

%package -n %{develname}
Summary:        Header files and development libraries for %{name}
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}

%description -n %{develname}
Header files and development libraries for %{name}.

%package -n fido2-tools
Summary:        FIDO2 tools
Group:          Development/Tools

%description -n fido2-tools
FIDO2 command line tools to access and configure a FIDO2 compliant
authentication device.

%prep
%autosetup -p1 -n %{name}-%{version}


%build
%cmake
%cmake_build


%install
%cmake_install

# Remove static files per packaging guidelines
find %{buildroot} -type f -name "*.a" -delete -print


%check
%ctest \-E regress_cred

%files -n %{libname}
%doc NEWS README.adoc
%license LICENSE
%{_libdir}/libfido2.so.%{major}{,.*}

%files -n %{develname}
%{_libdir}/pkgconfig/libfido2.pc
%{_libdir}/libfido2.so
%{_includedir}/fido.h
%{_includedir}/fido
%{_mandir}/man3/fido_*.3{,.*}
%{_mandir}/man3/eddsa_pk_*.3{,.*}
%{_mandir}/man3/es256_pk_*.3{,.*}
%{_mandir}/man3/es384_pk_*.3{,.*}
%{_mandir}/man3/rs256_pk_*.3{,.*}

%files -n fido2-tools
%{_bindir}/fido2-assert
%{_bindir}/fido2-cred
%{_bindir}/fido2-token
%{_mandir}/man1/fido2-assert.1{,.*}
%{_mandir}/man1/fido2-cred.1{,.*}
%{_mandir}/man1/fido2-token.1{,.*}


%changelog
* Mon Jun 30 2025 umeabot <umeabot> 1.15.0-3.mga10
+ Revision: 2230557
- Mageia 10 Mass Rebuild

* Sun Dec 01 2024 daviddavid <daviddavid> 1.15.0-2.mga10
+ Revision: 2120334
- rebuild for new libcbor 0.11.0

* Mon Aug 26 2024 mrambo3501 <mrambo3501> 1.15.0-1.mga10
+ Revision: 2091540
- version 1.15.0

* Mon Nov 27 2023 daviddavid <daviddavid> 1.14.0-1.mga10
+ Revision: 2010180
- new version: 1.14.0

* Wed Jun 14 2023 daviddavid <daviddavid> 1.13.0-2.mga9
+ Revision: 1961996
- fix fido2-tools dependency

* Mon Jun 12 2023 guillomovitch <guillomovitch> 1.13.0-1.mga9
+ Revision: 1961870
- imported package libfido2

